@@ -49,8 +49,6 @@ struct _GtkHTMLPrivate {
 
 	GnomePrintJob *print_master;
 
-	guint set_font_id;
-	guint notify_id;
 	guint notify_spell_id;
 
 	GtkIMContext *im_context;
@@ -63,18 +61,24 @@ struct _GtkHTMLPrivate {
 
 	guint32     event_time;
 	gboolean    selection_as_cite;
+
+	gboolean    magic_links;
+	gboolean    magic_smileys;
+	gboolean    inline_spelling;
 };
 
-void  gtk_html_private_calc_scrollbars  (GtkHTML                 *html,
-					 gboolean                *changed_x,
-					 gboolean                *changed_y);
-void  gtk_html_editor_event_command     (GtkHTML                 *html,
-					 GtkHTMLCommandType       com_type,
-					 gboolean                 before);
-void  gtk_html_editor_event             (GtkHTML                 *html,
-					 GtkHTMLEditorEventType   event,
-					 GValue                  *args);
-void  gtk_html_api_set_language         (GtkHTML                 *html);
-void  gtk_html_im_reset                 (GtkHTML                 *html);
+void  gtk_html_private_calc_scrollbars  (GtkHTML                *html,
+					 gboolean               *changed_x,
+					 gboolean               *changed_y);
+void  gtk_html_editor_event_command     (GtkHTML                *html,
+					 GtkHTMLCommandType      com_type,
+					 gboolean                before);
+void  gtk_html_editor_event             (GtkHTML                *html,
+					 GtkHTMLEditorEventType  event,
+					 GValue                 *args);
+void  gtk_html_api_set_language         (GtkHTML                *html);
+void  gtk_html_im_reset                 (GtkHTML                *html);
+void  gtk_html_set_fonts                (GtkHTML                *html,
+					 HTMLPainter            *painter);
 
 #endif /* _GTKHTML_PRIVATE_H */
